from django.contrib import admin
from django.contrib.contenttypes.generic import GenericStackedInline

import models
import eo_gestion.admin
from .. import actions
from eo_gestion.eo_facture.admin import PaymentInline

class CommentaireInlineAdmin(GenericStackedInline):
    model = models.Commentaire
    ordering = [ '-creation' ]
    extra = 0

class LigneBanquePopAdmin(admin.ModelAdmin):
    search_fields = [ 'montant', 'reference', 'libelle' ]
    inlines = [ PaymentInline, CommentaireInlineAdmin ]
    list_display=['date_valeur', 'libelle', 'montant', 'montant_non_affecte']
    readonly_fields = ['compte', 'date_comptabilisation', 'date_valeur',
            'libelle', 'reference', 'date_operation', 'montant', 'montant_non_affecte' ]
    date_hierarchy= 'date_valeur'
    ordering = [ '-date_valeur' ]
    actions = [ actions.export_as_csv ]

    def lookup_allowed(self, *args, **kwargs):
        return True

    def get_queryset(self, request):
        qs = super(LigneBanquePopAdmin, self).get_queryset(request)
        qs = qs.prefetch_related('payments')
        return qs

admin.site.register(models.LigneBanquePop, LigneBanquePopAdmin)
admin.site.register(models.SoldeBanquePop,
        list_display=['compte', 'date', 'montant'])

eo_gestion.admin.site.register(models.LigneBanquePop, LigneBanquePopAdmin)
eo_gestion.admin.site.register(models.SoldeBanquePop,
        list_display=['compte', 'date', 'montant'])
eo_gestion.admin.site.register(models.Commentaire)
