# -*- coding: utf8 -*-
from optparse import make_option
import sys
import csv
from datetime import datetime, date
# import xml.etree.ElementTree as etree

from django.core.management.base import BaseCommand, CommandError
from django.db import transaction

from eo_gestion.eo_banque.models import *

class Command(BaseCommand):
    '''
       Charge un fichier CSV exporté depuis notre banque en ligne Banque
       Populaire
    '''
    can_import_django_settings = True
    output_transaction = True
    requires_model_validation = True
    args = '<csv_file> <csv_file>...'
    help = 'Charge les fichiers CSVs'
    HEADER = [u"Compte",u"Date de comptabilisation",u"Date opération",u"Libellé",u"Référence",u"Date valeur",u"Montant",]

    def to_date(self, str):
        try:
            return datetime.strptime(str, '%Y/%m/%d').date()
        except:
            return datetime.strptime(str, '%d/%m/%Y').date()


    def to_utf8(self, iter):
        return map(lambda x: x.decode('latin1'), iter)


    def load_one_file(self, csv_file_path):
        csv_file = file(csv_file_path)
        csv_lines = csv.reader(csv_file, delimiter=';')
        first_line = self.to_utf8(csv_lines.next())
        if first_line != self.HEADER:
            print >>sys.stderr, 'Expecting this: %s' % (self.HEADER,)
            print >>sys.stderr, 'Got this      : %s' % first_line
            raise CommandError('Entête du fichier CSV invalide')
        counter = 0
        loaded = 0
        for line in csv_lines:
            compte, date_comptabilisation, date_operation, libelle, \
                    reference, date_valeur, montant,_ = line
            libelle = libelle.decode('latin1')
            # utilise un point décimal
            montant = montant.replace(',','.')
            date_comptabilisation = self.to_date(date_comptabilisation)
            date_operation = self.to_date(date_operation)
            date_valeur = self.to_date(date_valeur)
            ligne, created = LigneBanquePop.objects.get_or_create(
                    compte=compte, date_comptabilisation=date_comptabilisation,
                    date_operation=date_operation, libelle=libelle,
                    reference=reference, date_valeur=date_valeur,
                    montant=montant)
            counter += 1
            if created:
                loaded += 1
                ligne.save()
        print ' - %s: read %s lines, loaded %s lines.' % (csv_file_path,
                counter, loaded)

    @transaction.commit_manually
    def handle(self, *args, **options):
        try:
            for csv_file_path in args:
                self.load_one_file(csv_file_path)
        except:
            transaction.rollback()
            raise
        else:
            transaction.commit()
