# -*- encoding: utf-8 -*-
from decimal import *

from django import forms
from django.db.transaction import atomic
from django.core.exceptions import ValidationError

from . import models

pourcentages = [(Decimal(i)/100, "%s %%" % i) for i in range(0,101,5)]

class RapidFactureForm(forms.Form):
    contrat = forms.ModelChoiceField(queryset=models.Contrat.objects.all())
    pourcentage = forms.ChoiceField(choices = pourcentages,
            initial='1')
    solde = forms.BooleanField(required=False, label=u'Ignorer le pourcentage, et solder le contrat en une ligne.')

    def __init__(self, request=None, *args, **kwargs):
        self.request = request
        super(RapidFactureForm, self).__init__(*args, **kwargs)

    @atomic
    def clean(self):
        contrat = self.cleaned_data['contrat']
        pourcentage = Decimal(self.cleaned_data['pourcentage'])
        solde = self.cleaned_data['solde']
        facture = models.Facture(contrat=contrat,
                creator=self.request.user)
        try:
            facture.clean()
        except ValidationError, e:
            raise forms.ValidationError(*e.args)
        facture.save()
        self.cleaned_data['facture'] = facture
        lignes = []
        errors = []
        if solde:
            montant_solde = contrat.solde()
            if montant_solde == 0:
                raise ValidationError(u'Le solde du contrat est déjà nul.')
            models.Ligne.objects.create(facture=facture,
                    intitule=u'Solde',
                    prix_unitaire_ht=montant_solde,
                    quantite=Decimal(1))
        else:
            for prestation in contrat.prestations.all():
                ligne = models.Ligne(facture=facture, intitule=prestation.intitule,
                        prix_unitaire_ht=prestation.prix_unitaire_ht,
                        quantite=prestation.quantite*pourcentage)
                lignes.append(ligne)
                try:
                    ligne.clean()
                except ValidationError, e:
                    error = u'Il y a un problème avec la ligne « %s »: ' % prestation.intitule
                    error += '; '.join(map(lambda x: x.rstrip('.'), e.messages))
                    errors.append(error)
        if errors:
            raise forms.ValidationError(errors)
        else:
            for ligne in lignes:
                ligne.save()
        return self.cleaned_data

class DuplicateContractForm(forms.Form):
    contrat = forms.ModelChoiceField(queryset=models.Contrat.objects.all())
    new_intitule = forms.CharField(max_length=150, label=u'Nouvel intitulé')

    def __init__(self, request=None, *args, **kwargs):
        self.request = request
        super(DuplicateContractForm, self).__init__(*args, **kwargs)

    @atomic
    def clean(self):
        contrat = self.cleaned_data['contrat']
        new_intitule = self.cleaned_data['new_intitule']
        new_contrat = models.Contrat(client=contrat.client, intitule=new_intitule,
                description=contrat.description, tva=contrat.tva,
                creator=self.request.user)
        try:
            new_contrat.clean()
        except ValidationError, e:
            raise forms.ValidationError(*e.args)
        new_contrat.save()
        self.cleaned_data['new_contrat'] = new_contrat
        for prestation in contrat.prestations.all():
            new_prestation = prestation.duplicate()
            new_prestation.contrat = new_contrat
            new_prestation.save()
        return self.cleaned_data

class LigneForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Ligne
        localized_fields = ('quantite', 'prix_unitaire_ht', 'taux_tva')

class PrestationForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Prestation
        localized_fields = ('quantite', 'prix_unitaire_ht')

class FactureForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Facture
        localized_fields = ('taux_tva',)

class ClientForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Client
        localized_fields = ('tva',)

class ContratForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Contrat
        localized_fields = ('tva', 'montant_sous_traite')

class PaymentForm(forms.ModelForm):
    class Meta:
        exclude = ()
        model = models.Payment
        localized_fields = ('montant_affecte',)
